==> bw-xml-synchws-4.0.7-sources.jar: ietf/params/xml/ns/icalendar_2/IntegerPropertyType.java <==

package ietf.params.xml.ns.icalendar_2;

import java.math.BigInteger;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlSeeAlso;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for IntegerPropertyType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="IntegerPropertyType">
 *   &lt;complexContent>
 *     &lt;extension base="{urn:ietf:params:xml:ns:icalendar-2.0}BasePropertyType">
 *       &lt;sequence>
 *         &lt;element ref="{urn:ietf:params:xml:ns:icalendar-2.0}integer"/>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "IntegerPropertyType", propOrder = {
    "integer"
})
@XmlSeeAlso({
    PercentCompletePropType.class,
    PriorityPropType.class,
    PollItemIdPropType.class,
    XBedeworkMaxTicketsPropType.class,
    XBedeworkMaxTicketsPerUserPropType.class,
    SequencePropType.class,
    RepeatPropType.class
})
public class IntegerPropertyType
    extends BasePropertyType
{

    @XmlElement(required = true)
    protected BigInteger integer;

    /**
     * Gets the value of the integer property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getInteger() {
        return integer;
    }

    /**
     * Sets the value of the integer property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setInteger(BigInteger value) {
        this.integer = value;
    }

}

==> bw-xml-synchws-4.0.9-sources.jar: ietf/params/xml/ns/icalendar_2/IntegerPropertyType.java <==

package ietf.params.xml.ns.icalendar_2;

import java.math.BigInteger;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlSeeAlso;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for IntegerPropertyType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="IntegerPropertyType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{urn:ietf:params:xml:ns:icalendar-2.0}BasePropertyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element ref="{urn:ietf:params:xml:ns:icalendar-2.0}integer"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "IntegerPropertyType", propOrder = {
    "integer"
})
@XmlSeeAlso({
    PercentCompletePropType.class,
    PriorityPropType.class,
    RepeatPropType.class,
    SequencePropType.class,
    PollItemIdPropType.class,
    XBedeworkMaxTicketsPropType.class,
    XBedeworkMaxTicketsPerUserPropType.class
})
public class IntegerPropertyType
    extends BasePropertyType
{

    @XmlElement(required = true)
    protected BigInteger integer;

    /**
     * Gets the value of the integer property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getInteger() {
        return integer;
    }

    /**
     * Sets the value of the integer property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setInteger(BigInteger value) {
        this.integer = value;
    }

}
